@@ -86,7 +86,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -157,9 +157,28 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_78(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_80(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_80(text)
+#endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_82(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCONFIGWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCONFIGWIDGETS_EXPORT_H */
